@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::WordList;
 
-our $DATE = '2016-01-13'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2017-12-24'; # DATE
+our $VERSION = '0.050'; # VERSION
 
 use 5.014;
 use strict;
@@ -19,6 +19,11 @@ with (
     },
 );
 
+sub __length_in_graphemes {
+    my $length = () = $_[0] =~ m/\X/g;
+    return $length;
+}
+
 sub munge_files {
     no strict 'refs';
     my $self = shift;
@@ -55,7 +60,7 @@ sub munge_files {
                     $stats{num_words_contains_unicode}++ if $word =~ /[\x80-\x{10ffff}]/;
                     $stats{num_words_contains_whitespace}++ if $word =~ /\s/;
                     $stats{num_words_contains_nonword_chars}++ if $word =~ /\W/u;
-                    my $len = length($word);
+                    my $len = __length_in_graphemes($word);
                     $total_len += $len;
                     $stats{shortest_word_len} = $len
                         if !defined($stats{shortest_word_len}) ||
@@ -80,8 +85,6 @@ __PACKAGE__->meta->make_immutable;
 1;
 # ABSTRACT: Plugin to use when building WordList::* distribution
 
-
-
 __END__
 
 =pod
@@ -94,7 +97,7 @@ Dist::Zilla::Plugin::WordList - Plugin to use when building WordList::* distribu
 
 =head1 VERSION
 
-This document describes version 0.04 of Dist::Zilla::Plugin::WordList (from Perl distribution Dist-Zilla-Plugin-WordList), released on 2016-01-13.
+This document describes version 0.050 of Dist::Zilla::Plugin::WordList (from Perl distribution Dist-Zilla-Plugin-WordList), released on 2017-12-24.
 
 =head1 SYNOPSIS
 
@@ -115,12 +118,6 @@ it does the following:
 
 =for Pod::Coverage .+
 
-=head1 SEE ALSO
-
-L<WordList>
-
-L<Pod::Weaver::Plugin::WordList>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Dist-Zilla-Plugin-WordList>.
@@ -137,16 +134,21 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<WordList>
+
+L<Pod::Weaver::Plugin::WordList>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
